csi_utils documentation

# csi_images: documentation

Welcome to the csi_images documentation. Please use the "Available Modules" list on the left to access what you need. Top-level modules include:

- csi_images: the main modules that you may find useful.
- examples: a collection of examples to help you get started.
- tests: the test suite for the package, which you might check out for further examples.
- scripts: a collection of scripts that are used in the lab.

To modify this page, please edit the `docs/theme/index.html.jinja2` file in the repository.